<h3 align="center"><b>Hut Services</b></h3>
<p align="center">
  <a href="https://wodore.github.io/hut-services"><img src="https://wodore.github.io/hut-services/assets/favicon.png" alt="Hut Services" width="80" /></a>
</p>
<p align="center">
    <em>Retrieve mountain hut informations.</em>
</p>
<p align="center">
    <b><a href="https://wodore.github.io/hut-services/docu/">Documentation</a></b>
    | <b><a href="https://pypi.org/project/hut-services/">PyPi</a></b>
</p>

---

[![Release](https://img.shields.io/github/v/release/wodore/hut-services)](https://img.shields.io/github/v/release/wodore/hut-services)
[![Build status](https://img.shields.io/github/actions/workflow/status/wodore/hut-services/main.yml?branch=main)](https://github.com/wodore/hut-services/actions/workflows/main.yml?query=branch%3Amain)
[![License](https://img.shields.io/github/license/wodore/hut-services)](https://img.shields.io/github/license/wodore/hut-services)


**Hut Services** is a tool to get (mountain) hut information from different sources.

For more information check out the [**documentation**](https://wodore.github.io/hut-services/docu/).
